==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/models/common/util/ICommonConstants.java <==
/*******************************************************************************
 * Copyright (c) 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.models.common.util;


/**
 * @author marcelop
 * @since 0.3.0
 */
public interface ICommonConstants
{
	/**
	 * The Test UI default enconding for XML and XMI files. 
	 */
	public final static String DEFAULT_ENCODING = "UTF-8";
	
	/**
	 * File extension for the test suite resources
	 */
	public final static String TEST_SUITE_FILE_EXTENSION = "testsuite";

	/**
	 * Extension ientifier for the execution objects
	 */
	public final static String EXECUTION_FILE_EXTENSION = "execution";

	/**
	 * File extension for the deployment resources
	 */
	public final static String DEPLOYMENT_FILE_EXTENSION = "deploy";

	/**
	 * Extension identifier for the test case objects
	 */
	public final static String TEST_CASE_EXTENSION = "testcase";

	/**
	 * Extension identifier for the test component objects
	 */
	public final static String TEST_COMPONENT_EXTENSION = "testcomponent";

	/**
	 * Extension identifier for the sut objects
	 */
	public final static String SUT_EXTENSION = "sut";
}

==> hyades.source_1.2.1_20040126_0954.zip: org/eclipse/hyades/models/common/util/ICommonConstants.java <==
/*******************************************************************************
 * Copyright (c) 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.models.common.util;


/**
 * @author marcelop
 * @since 0.3.0
 */
public interface ICommonConstants
{
	/**
	 * The Test UI default enconding for XML and XMI files. 
	 */
	public final static String DEFAULT_ENCODING = "UTF-8";
	
	/**
	 * File extension for the test suite resources
	 */
	public final static String TEST_SUITE_FILE_EXTENSION = "testsuite";

	/**
	 * Extension ientifier for the execution objects
	 */
	public final static String EXECUTION_FILE_EXTENSION = "execution";

	/**
	 * File extension for the deployment resources
	 */
	public final static String DEPLOYMENT_FILE_EXTENSION = "deploy";

	/**
	 * Extension identifier for the test case objects
	 */
	public final static String TEST_CASE_EXTENSION = "testcase";

	/**
	 * Extension identifier for the test component objects
	 */
	public final static String TEST_COMPONENT_EXTENSION = "testcomponent";

	/**
	 * Extension identifier for the sut objects
	 */
	public final static String SUT_EXTENSION = "sut";
	/**
	 * Extension identifier for the datapool objects
	 */
	public final static String DATAPOOL_FILE_EXTENSION = "datapool";


}
